"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DEFAULT_NETWORK = exports.CONFIG = exports.networkPlatformConfigs = exports.chainConfigs = void 0;
const sdk_base_1 = require("@wormhole-foundation/sdk-base");
const sdk_definitions_1 = require("@wormhole-foundation/sdk-definitions");
/*
TODO:
    add missing chains for each config
 Note: the false exclamation marks here are because not every chain
    is represented in the consts we're pulling from yet
*/
function combineConfig(n) {
    const cc = sdk_base_1.chains
        .map((c) => {
        const platform = (0, sdk_base_1.chainToPlatform)(c);
        return {
            key: c,
            platform,
            finalityThreshold: sdk_base_1.finalityThreshold.get(n, c) || 0,
            contracts: (0, sdk_definitions_1.getContracts)(n, c),
            nativeTokenDecimals: sdk_base_1.nativeDecimals.get(platform),
            explorer: (0, sdk_base_1.explorerConfigs)(n, c),
            rpc: (0, sdk_base_1.rpcAddress)(n, c), //TODO the exclamation mark is a lie
        };
    })
        .reduce((acc, curr) => {
        return { ...acc, [curr.key]: curr };
    }, {});
    return cc;
}
// Combine all the configs for each network/chain
const chainConfigMapping = [
    ["Mainnet", combineConfig("Mainnet")],
    ["Testnet", combineConfig("Testnet")],
    ["Devnet", combineConfig("Devnet")],
];
exports.chainConfigs = (0, sdk_base_1.constMap)(chainConfigMapping);
function networkPlatformConfigs(network, platform) {
    return Object.fromEntries(Object.entries((0, exports.chainConfigs)(network)).filter(([_, v]) => {
        return v.platform == platform;
    }));
}
exports.networkPlatformConfigs = networkPlatformConfigs;
const sharedConfig = {
    network: "Testnet",
    //api: 'https://api.testnet.wormholescan.io',
    api: "https://api.testnet.wormscan.io",
    circleAPI: (0, sdk_base_1.circleAPI)("Testnet"),
    chains: (0, exports.chainConfigs)("Testnet"),
};
exports.CONFIG = {
    Mainnet: {
        network: "Mainnet",
        api: "https://api.wormholescan.io",
        circleAPI: (0, sdk_base_1.circleAPI)("Mainnet"),
        chains: (0, exports.chainConfigs)("Mainnet"),
    },
    Testnet: sharedConfig,
    Devnet: sharedConfig,
};
exports.DEFAULT_NETWORK = process.env.NETWORK || "Testnet";
//# sourceMappingURL=config.js.map