import { NativeAddress, UniversalAddress, VAA, Signer, TxHash, WormholeMessageId, TransactionId } from "@wormhole-foundation/sdk-definitions";
import { TokenTransferDetails } from "../types";
import { WormholeTransfer, TransferState, AttestationId } from "../wormholeTransfer";
import { Wormhole } from "../wormhole";
import { ChainName, PlatformName } from "@wormhole-foundation/sdk-base";
/**
 * What do with multiple transactions or VAAs?
 * More concurrent promises instead of linearizing/blocking
 */
export declare class TokenTransfer implements WormholeTransfer {
    private readonly wh;
    private state;
    transfer: TokenTransferDetails;
    txids?: TxHash[];
    vaas?: {
        id: WormholeMessageId;
        vaa?: VAA<"Transfer"> | VAA<"TransferWithPayload">;
    }[];
    private constructor();
    getTransferState(): Promise<TransferState>;
    static from(wh: Wormhole, from: TokenTransferDetails): Promise<TokenTransfer>;
    static from(wh: Wormhole, from: WormholeMessageId): Promise<TokenTransfer>;
    static from(wh: Wormhole, from: TransactionId): Promise<TokenTransfer>;
    private static fromIdentifier;
    private static fromTransaction;
    initiateTransfer(signer: Signer): Promise<TxHash[]>;
    fetchAttestation(): Promise<AttestationId[]>;
    completeTransfer(signer: Signer): Promise<TxHash[]>;
    static getTransferVaa(wh: Wormhole, chain: ChainName, emitter: UniversalAddress | NativeAddress<PlatformName>, sequence: bigint, retries?: number): Promise<VAA<"Transfer"> | VAA<"TransferWithPayload">>;
}
//# sourceMappingURL=tokenTransfer.d.ts.map