import { chains, chainToPlatform, explorerConfigs, finalityThreshold, nativeDecimals, rpcAddress, constMap, circleAPI, } from "@wormhole-foundation/sdk-base";
import { getContracts, } from "@wormhole-foundation/sdk-definitions";
/*
TODO:
    add missing chains for each config
 Note: the false exclamation marks here are because not every chain
    is represented in the consts we're pulling from yet
*/
function combineConfig(n) {
    const cc = chains
        .map((c) => {
        const platform = chainToPlatform(c);
        return {
            key: c,
            platform,
            finalityThreshold: finalityThreshold.get(n, c) || 0,
            contracts: getContracts(n, c),
            nativeTokenDecimals: nativeDecimals.get(platform),
            explorer: explorerConfigs(n, c),
            rpc: rpcAddress(n, c), //TODO the exclamation mark is a lie
        };
    })
        .reduce((acc, curr) => {
        return { ...acc, [curr.key]: curr };
    }, {});
    return cc;
}
// Combine all the configs for each network/chain
const chainConfigMapping = [
    ["Mainnet", combineConfig("Mainnet")],
    ["Testnet", combineConfig("Testnet")],
    ["Devnet", combineConfig("Devnet")],
];
export const chainConfigs = constMap(chainConfigMapping);
export function networkPlatformConfigs(network, platform) {
    return Object.fromEntries(Object.entries(chainConfigs(network)).filter(([_, v]) => {
        return v.platform == platform;
    }));
}
const sharedConfig = {
    network: "Testnet",
    //api: 'https://api.testnet.wormholescan.io',
    api: "https://api.testnet.wormscan.io",
    circleAPI: circleAPI("Testnet"),
    chains: chainConfigs("Testnet"),
};
export const CONFIG = {
    Mainnet: {
        network: "Mainnet",
        api: "https://api.wormholescan.io",
        circleAPI: circleAPI("Mainnet"),
        chains: chainConfigs("Mainnet"),
    },
    Testnet: sharedConfig,
    Devnet: sharedConfig,
};
export const DEFAULT_NETWORK = process.env.NETWORK || "Testnet";
//# sourceMappingURL=config.js.map